@@ -1,6 +1,6 @@
-import logging
-
+from ..logger import logger
 from .captcha import Captcha
+from ..exceptions import NoCaptchaException
 
 
 class ReCaptchaV2(Captcha):
@@ -14,7 +14,11 @@ class ReCaptchaV2(Captcha):
 
         :return: True if solved
         """
-        self._get_data()
+        try:
+            self._get_data()
+        except Exception:
+            raise NoCaptchaException("Cannot find ReCaptchaV2 on the page!")
+
         payload = "method=userrecaptcha&googlekey={}&pageurl={}".format(self.key, self.page_url)
         self.service_provider.get_in(payload)
         self.token = self.service_provider.get_res()
@@ -72,7 +76,7 @@ let res = findRecaptchaClients();
 return res
         """
         )
-        logging.info(data)
+        logger.info(data)
         self.key = data[0]["sitekey"]
         self.page_url = data[0]["pageurl"]
         self.function = data[0]["function"]
