@@ -29,9 +29,9 @@ class TACaptchaSolver(object):
         Return instance of captcha according to provided params
 
         :param params: Captcha settings. Possible values:
-            - captcha_type: 'v2' or 'image'. Required
+            - captcha_type: 'v2' or 'image' or 'fun_captcha'. Required
             - browser: Instance of RPA.Browser.Selenium.Selenium().
-                       Required for 'v2' and 'image' captcha in case image_source is not provided
+                       Required for 'v2' and 'image' and 'fun_captcha' captcha in case image_source is not provided
             - captcha_guru_api_key: Valid api key. Deprecated.
                        Use 'service_provider_name' + 'service_provider_key' instead!
             - service_provider_name: 'captcha.guru' or '2captcha'. Required
@@ -87,7 +87,7 @@ class TACaptchaSolver(object):
             elif not (".jpg" in params["image_source"] or ".png" in params["image_source"]) and (not params["browser"]):
                 raise ParamsException("No image path valid provided on image_source. Cannot work without a valid path!")
 
-        if params["captcha_type"] == "v2":
+        if params["captcha_type"] == "v2" or params["captcha_type"] == "fun_captcha":
             if not params["browser"]:
                 raise ParamsException("No browser provided. Cannot work wiithout any browser!")
 
